unit Preview1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, DB, DBTables, Mask, DBCtrls, ShellAPI, Printers,
  ExtCtrls, PrintDrv, Buttons;

const
	LeftMargin:double = 0.5;
  RightMargin:double = 8.0;
  TopMargin:double = 0.5;
  BottomMargin:double = 10.5;

type
  TMainForm = class(TForm)
    Label1: TLabel;
    Demo1: TButton;
    PrintOrient: TCheckBox;
    Image1: TImage;
    Demo2: TButton;
    MemoDemo: TMemo;
    Prn: TPrintObject;
    procedure Demo1Click(Sender: TObject);
    procedure Demo2Click(Sender: TObject);
    procedure PrnNewPage(Sender: TObject);
    procedure SetPageDefaults;
  private
    { Private declarations }
    procedure DoTestPreview;
    procedure PrintTestFile;
    procedure PrintTestDemo;
    procedure CreateColumns;
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;
  TestNumber: integer;
  Shading: integer;

implementation

{$R *.DFM}

procedure TMainForm.SetPageDefaults;
// I usually create separate default routines so that I can call them separately
// based on the type of report I want to perform.
begin
	with Prn do
  begin
    	SetFontInformation('Times New Roman',10,[]);
      SetMargins(TopMargin,BottomMargin,LeftMargin,RightMargin);
    	SetHeaderInformation(1,0.625,'Test Preview Program',1,'Times New Roman',16,[fsBold]);
    	SetHeaderInformation(2,0.850,'Second Header Line',1,'Times New Roman',12,[]);
      SaveCurrentFont;
    	SetFontInformation('Times New Roman',16,[fsBold]);
    	SetHeaderDimensions(0.25,0.25,RightMargin,0.625 + (GetLineHeightInches * 2),False,0,255);
      SetDetailTopBottom(0.625 + (GetLineHeightInches * 2),BottomMargin - 1.25);
      RestoreCurrentFont;
      case TestNumber of
      	1: SetPageNumberInformation(0.5,'Page %d',2,True,'Times New Roman',10,[]);
        2: SetPageNumberInformation(BottomMargin + 0.35,'Page %d',1,
        		True,'Times New Roman',10,[]);
      end;
    	SetFooterDimensions(LeftMargin,BottomMargin - 1.0,RightMargin,BottomMargin,False,0,255);
      SetFooterInformation(1,10.6,'Page Footer Line #1.',1,'Arial',10,[]);
      MemoDemo.Font.Name := 'TimesNewRoman';
      MemoDemo.Font.Size := 10;
      MemoDemo.Font.Style := [];
  end;
end;

Procedure TMainForm.DoTestPreview;
// entry point for both demo print routines to set up the defaults
var
	TempX: single;

begin
  try
  	Hide;
    Shading := 235;
    with Prn do
    begin
      if PrintOrient.Checked then
      begin
      	Orientation := poLandscape;
    		RightMargin := 10.5;
        BottomMargin := 8.0;
      end
      else
      begin
      	Orientation := poPortrait;
    		RightMargin := 8.0;
        BottomMargin := 10.5;
      end;
  		Start;
      SetPageDefaults;
			MemoDemo.Width := InchesToPixelsHorizontal(3.5);
  		MemoDemo.Text := '     This is some text put into a memo box. In order to '+
  										 'print the text of a memo control, I usually adjust the '+
          		         'size of the memo box to the width of the text as I want '+
              		     'it to appear on the form. This makes use of the automatic '+
                  		 'word wrap feature. Then just loop through the lines and '+
		                   'print! This text should wrap inside of 3.5".';
      case TestNumber of
      	1: PrintTestFile;
        2: PrintTestDemo;
      end;
      NextLine;
      WriteLineCenter(-1,'*** End of test ***');
      Quit;
    end;
  finally
  	Show;
  end;
end;

procedure TMainForm.PrintTestFile;
// demo printing for AutoPaging set to true
var
	tFile: TextFile;
  sLine: string;
  fY: integer;
  fX,fW: single;

begin
	try
		with Prn do
  	begin
    	if Not FileExists(ExtractFilePath(ParamStr(0))+'Readme.Txt') then
      begin
      	ShowMessage('Could not find test file...');
        exit;
      end;
      AutomaticPaging := true;
			AssignFile(tFile,ExtractFilePath(ParamStr(0))+'Readme.Txt');
      Reset(tFile);
      fY := 0;
      SetYPosition(PixelsToInchesVertical(Image1.Height div 2) + TopMargin);
      while not Eof(tFile) do //first loop to get a test count for progress bar...
      begin
      	readln(tFile,sLine);
        inc(fY);
      end;
      fX := 100 / fY;
      fW := 0.0;
      CloseFile(tFile);
			AssignFile(tFile,ExtractFilePath(ParamStr(0))+'Readme.Txt');
      Reset(tFile);
      SetTopOfPage;
      NextLine;
      while not Eof(tFile) do
      begin
      	Readln(tFile,sLine);
        WriteLine(0.5,-1,sLine);
        fW := fW + fX;
        UpdateBar(trunc(fW));
      end;
			CloseFile(tFile);
  	end;
  except
  	on Exception do
    	ShowMessage('Sorry, something didn''t work right!');
  end;
end;

procedure TMainForm.PrintTestDemo;
// demo printing for AutoPaging set to false for manual control.
var
	x,y: integer;

begin
	with Prn do
  begin
  	ProgressBarInc := 2;
  	AutomaticPaging := false;
		SetTopOfPage;
    CreateColumns;
    DrawTextBox(GetColumnLeft(1),GetYPosition - 0.02,GetColumnRight(1),
    						GetYPosition + GetLineHeightInches + 0.02,1,Shading,
                'Column 1',1,1);
    DrawTextBox(GetColumnLeft(2),GetYPosition - 0.02,GetColumnRight(2),
    						GetYPosition + GetLineHeightInches + 0.02,1,Shading,
                'Column 2',2,1);
    DrawTextBox(GetColumnLeft(3),GetYPosition - 0.02,GetColumnRight(3),
    						GetYPosition + GetLineHeightInches + 0.02,1,Shading,
                'Column 3',3,1);
    DrawTextBox(GetColumnLeft(4),GetYPosition - 0.02,GetColumnRight(4),
    						GetYPosition + GetLineHeightInches + 0.02,1,Shading,
                'Column 4',4,1);
		NextLine;
    IncBar(10);
    WriteLine(LeftMargin,-1.0,'Centered column text...');
    NextLine;
    for x := 1 to 10 do
    begin
    	for y := 1 to 4 do
      	WriteLineColumnCenter(y,GetYPosition,'Line: ' + IntToStr(x) + '  Col: ' + IntToStr(y));
      NextLine;
      Increment;
    end;
    NextLine;
    WriteLine(LeftMargin,-2.0,'Left justified column text...');
    NextLine;
    for x := 1 to 10 do
    begin
    	for y := 1 to 4 do
      	WriteLineColumn(y,GetYPosition,'Line: ' + IntToStr(x) + '  Col: ' + IntToStr(y));
      NextLine;
      Increment;
    end;
    NextLine;
    WriteLine(LeftMargin,-1.0,'Right justified column text...');
    NextLine;
    for x := 1 to 10 do
    begin
    	for y := 1 to 4 do
      	WriteLineColumnRight(y,-2.0,'Line: ' + IntToStr(x) + '  Col: ' + IntToStr(y));
      NextLine;
      Increment;
    end;
    NewPage;
    SetTab(0.1);
    WriteLine(LeftMargin,-1.0,'[Shaded Box]');
    SetTab(0.0);
    Increment;
    DrawBoxShaded(LeftMargin,GetYPosition - 0.1,1.5,3.0,4,Shading);
    Increment;
    WriteLine(2.6,-2.0,'[Regular Box]');
    DrawBox(2.4,GetYPosition - 0.1,4.0,GetYPosition + 0.3,1);
    Increment;
    SetYPosition(3.0);
    WriteLineCenter(-1.0,'Center Justification');
    Increment;
    SaveCurrentFont;
    SetFontInformation('Arial',8,[fsBold,fsUnderline]);
    WriteLineRight(-2.0,'Right Justified Text [fsBold,fsUnderline]');
    RestoreCurrentFont;
    Increment;
    SetYPosition(6.0);
    WriteLine(LeftMargin,-1.0,'Text printed without a tab set...');
    SetTab(0.25);
    WriteLine(LeftMargin,-1.0,'Text printed using a 0.25" tab setting...');
    SetTab(0.0);
    NextLine;
    WriteLine(LeftMargin,-1.0,'Equation:  2x');
    x := GetTextWidth('Equation:  2x ');
    SaveCurrentFont;
    SetFontInformation(GetFontName,6,[]);
    WriteLine(LeftMargin + PixelsToInchesHorizontal(x),GetYPosition - 0.02,'2');
    x := x + GetTextWidth('2');
    RestoreCurrentFont;
    WriteLine(LeftMargin + PixelsToInchesHorizontal(x),-2.0,' = 12');
    NextLine;
    WriteLine(LeftMargin,-1.0,'Memo field printing...');
    DrawBox(LeftMargin,GetYPosition + GetLineHeightInches,LeftMargin + 3.6,
    				GetYPosition + ((MemoDemo.Lines.Count + 1) * GetLineHeightInches) + 0.05,1);
    SetTab(0.05);
    for x := 0 to MemoDemo.Lines.Count-1 do
    begin
    	WriteLine(LeftMargin,-1.0,MemoDemo.Lines[x]);
      Increment;
    end;
    UpdateBar(100);
  end;
end;

procedure TMainForm.CreateColumns;
{This procedure sets up a few columns}
begin
	with Prn do
  begin
  	CreateColumn(1,0.5,1.5); //column 1
    CreateColumn(2,2.5,1.5); //column 2
    CreateColumn(3,4.5,1.5); //column 3
    CreateColumn(4,6.5,1.5); //column 4
  end;
end;

procedure TMainForm.Demo1Click(Sender: TObject);
// do automatic paging demo
begin
	TestNumber := 1;
	DoTestPreview;
end;

procedure TMainForm.Demo2Click(Sender: TObject);
// do manual paging demo
begin
	TestNumber := 2;
	DoTestPreview;
end;

procedure TMainForm.PrnNewPage(Sender: TObject);
// This routine is called in the OnNewPage event to place my graphic
// at the top of each page.
begin
	Prn.PrintGraphic(0.25,0.25,-1.0,-1.0,Image1);
end;

end.
